<?php

namespace Litecms\Company\Http\Controllers;

use Exception;
use Litecms\Company\Actions\CompanyWorkflow;
use Litecms\Company\Http\Requests\CompanyWorkflowRequest;
use Litecms\Company\Http\Resources\CompanyResource;
use Litecms\Company\Models\Company;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class CompanyWorkflowController extends BaseController
{
    /**
     * Action controller function for company.
     *
     * @param Model $company
     * @param action next action for the company.
     *
     * @return Response
     */
    public function __invoke(CompanyWorkflowRequest $request, Company $company, $trasition)
    {
        try {
            $request = $request->all();
            $company = CompanyWorkflow::run($trasition, $company, $request);
            $data = new CompanyResource($company);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('company::company.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('company/company/' . $company->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/company/' . $company->getRouteKey()))
                ->redirect();
        }
    }
}
