<?php
namespace Litecms\Company\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Company\Events\CompanyAction as CompanyActionEvent;
use Litecms\Company\Models\Company;

class CompanyAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $company;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param CompanyActionEvent $company
     * @param string $action
     */
    public function __construct(CompanyActionEvent $company, string $action)
    {
        $this->action = $action;
        $this->company = $company;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Company Approved - ' . config('app.name'))
            ->view('company::company.email.action', ['data' => $this->company]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
