<?php

namespace Litecms\Company\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Company\Models\Company;

class CompanyPolicy
{

    use CompanyAction;
    use CompanyExim;
    use CompanyReport;
    use CompanyWorkflow;

    /**
     * Determine if the given user can view the company.
     *
     * @param UserPolicyInterface $authUser
     * @param Company $company
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Company $company)
    {
        if ($authUser->canDo('company.company.view') && $authUser->isAdmin()) {
            return true;
        }

        return $company->user_id == user_id() && $company->user_type == user_type();
    }

    /**
     * Determine if the given user can create a company.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('company.company.create');
    }

    /**
     * Determine if the given user can update the given company.
     *
     * @param UserPolicyInterface $authUser
     * @param Company $company
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Company $company)
    {
        if ($authUser->canDo('company.company.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $company->user_id == user_id() && $company->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given company.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Company $company)
    {
        return $company->user_id == user_id() && $company->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given company.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Company $company)
    {
        if ($authUser->canDo('company.company.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given company.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Company $company)
    {
        if ($authUser->canDo('company.company.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
